| Title: | Fisheries data reporting flows |
|---|---|
| Description: | R framework to facilitate fisheries data reporting flows, with first intention to help countries to validate, format and send data to relevant organizations including regional fisheries management organizations or bodies handling data collection reference frameworks, and FAO. |
| Authors: | Emmanuel Blondel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5870-5762>), Arturo Muñoz Albero [ctb] |
| Maintainer: | Emmanuel Blondel <[email protected]> |
| License: | MIT |
| Version: | 0.1.20260528 |
| Built: | 2026-07-10 10:40:23 UTC |
| Source: | https://github.com/fdiwg/repfishr |
Get reporting flow actors
get_reporting_flow_actors()get_reporting_flow_actors()
Fills an ICCAT template workbook with a dataset
iccat_fill_report_statistical_correspondent(wb, metadata)iccat_fill_report_statistical_correspondent(wb, metadata)
wb |
a |
sheet |
a sheet index |
x |
an object of class data.frame |
startRow |
start row index |
startCol |
start column index |
the modified Workbook object
Fills an ICCAT template workbook with dataset characteristics information
iccat_fill_report_dataset_characteristics( wb, reporting_flag, from, to, report_version, report_type, report_coverage )iccat_fill_report_dataset_characteristics( wb, reporting_flag, from, to, report_version, report_type, report_coverage )
wb |
a |
metadata |
a named list with business metadata |
the modified Workbook object
Fills an ICCAT template workbook with statistical correspondent information
iccat_fill_report_statistical_correspondent(wb, metadata)iccat_fill_report_statistical_correspondent(wb, metadata)
wb |
a |
metadata |
a named list with business metadata |
the modified Workbook object
R framework to facilitate fisheries data reporting flows, with first intention to help countries to validate, format and send data to relevant organizations including regional fisheries management organizations or bodies handling #' data collection reference frameworks, and FAO.
Emmanuel Blondel [email protected]
Useful links:
reporting_actor
reporting_actor
Object of class R6Class for modelling a reporting actor
idid
namename,
typetype
new()
Initializes a reporting sender
reporting_actor$new(id, name = NULL, type = NULL)
idid
namename
typetype
clone()
The objects of this class are cloneable with this method.
reporting_actor$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <[email protected]>
reporting_flow
reporting_flow
Object of class R6Class for modelling a reporting flow
sendersender object of class reporting_sender
new()
Initializes a reporting flow
reporting_flow$new(sender, sender_type)
sendersender id
sender_typetype of sender
getSender()
Get sender
reporting_flow$getSender()
an object of class reporting_sender
getReceivers()
Get list of valid receivers for the selected sender
reporting_flow$getReceivers(raw = FALSE)
rawraw
an object of class data.frame or a list of reporting_receiver
getReceiverIds()
Get list of valid receivers IDs
reporting_flow$getReceiverIds()
getReceiver()
Get a receiver by its id
reporting_flow$getReceiver(id)
idid
an object of class reporting_organization
clone()
The objects of this class are cloneable with this method.
reporting_flow$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <[email protected]>
reporting_format
reporting_format
Object of class R6Class for modelling a reporting format
idid
namename
refref format specification link
specformat specification object of class format_spec
new()
Initializes a reporting task
reporting_format$new(id, name, ref)
idid
namename
refref
clone()
The objects of this class are cloneable with this method.
reporting_format$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <[email protected]>
reporting_receiver
reporting_receiver
Object of class R6Class for modelling a reporting receiver
repfishr::reporting_actor -> reporting_receiver
sendersender
taskstasks
new()
Initializes a reporting receiver
reporting_receiver$new(id, name = NULL, type = NULL)
idid
namename
typetype
setSender()
Set sender
reporting_receiver$setSender(sender)
sendersender object of class reporting_sender
getTasks()
Get task IDs
reporting_receiver$getTasks()
the list of task IDs
getTaskDefinitions()
Get tasks
reporting_receiver$getTaskDefinitions(raw = FALSE)
rawraw
a list of reporting_task
getTaskDefinitionById()
Get task definition by ID
reporting_receiver$getTaskDefinitionById(id)
idid
an object of class reporting_task
clone()
The objects of this class are cloneable with this method.
reporting_receiver$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <[email protected]>
reporting_sender
reporting_sender
Object of class R6Class for modelling a reporting sender
repfishr::reporting_actor -> reporting_sender
new()
Initializes a reporting sender
reporting_sender$new(id, name = NULL, type = NULL)
idid
namename
typetype
clone()
The objects of this class are cloneable with this method.
reporting_sender$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <[email protected]>
reporting_task
reporting_task
Object of class R6Class for modelling a reporting task
sendersender
receiverreceiver
idid
namename
contextcontext
measurementmeasurement
formatsformats
process_funprocess handler (function)
report_funreport handler (function)
report_datadata to report
report_metadatametadata to report
new()
Initializes a reporting task
reporting_task$new(receiver = NULL, file = NULL, task = NULL)
receiverreceiver
filefile
tasktask (as list object)
setSender()
Set sender
reporting_task$setSender(sender)
sendersender object of class reporting_sender
process()
Process data before reporting
reporting_task$process(data, metadata, path, parallel = FALSE, ...)
dataobject of class data.frame
metadatametadata object
pathpath for the output file
parallelwhether data validation should be run in parallel
...any other arguments to be passed to vrule validation method
report()
Reports data
reporting_task$report(data, metadata, path, parallel = FALSE, ...)
dataobject of class data.frame
metadatametadata object
pathpath for the output file
parallelwhether data validation should be run in parallel
...any other arguments to be passed to vrule validation method
clone()
The objects of this class are cloneable with this method.
reporting_task$clone(deep = FALSE)
deepWhether to make a deep clone.
Emmanuel Blondel <[email protected]>